.. -*- coding: utf-8 -*-

.. _Tutorial:

.. _tuto_blog:

Building a simple blog
======================

*CubicWeb* is a semantic web application framework that favors reuse and
object-oriented design.

A `cube` is a component that includes a model defining the data types and a set of
views to display the data. A cube can be built by assembling other cubes.

An `instance` is a specific installation of a cube and includes configuration
files.


This tutorial will show how to create a `cube` and how to use it as an
application to run an `instance`.

.. toctree::
   :maxdepth: 2

   blog-in-five-minutes
   create-cube
   components
   maintemplate
   conclusion
